summaryrefslogtreecommitdiffstats
path: root/tdeui/klineedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/klineedit.h')
-rw-r--r--tdeui/klineedit.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/tdeui/klineedit.h b/tdeui/klineedit.h
index be25a35d9..82179fa05 100644
--- a/tdeui/klineedit.h
+++ b/tdeui/klineedit.h
@@ -35,7 +35,7 @@
class TQPopupMenu;
-class KCompletionBox;
+class TDECompletionBox;
class KURL;
/**
@@ -63,7 +63,7 @@ class KURL;
*
* This widget by default creates a completion object when you invoke
* the completionObject( bool ) member function for the first time or
* use setCompletionObject( KCompletion*, bool ) to assign your own
* completion object. Additionally, to make this widget more functional,
* KLineEdit will by default handle the text rotation and completion
* events internally when a completion object is created through either one
@@ -82,7 +82,7 @@ class KURL;
* If @p EchoMode for this widget is set to something other than @p TQLineEdit::Normal,
* the completion mode will always be defaulted to TDEGlobalSettings::CompletionNone.
* This is done purposefully to guard against protected entries such as passwords being
* cached in KCompletion's list. Hence, if the @p EchoMode is not TQLineEdit::Normal, the
* completion mode is automatically disabled.
*
* A read-only KLineEdit will have the same background color as a
@@ -97,7 +97,7 @@ class KURL;
*
* \code
* KLineEdit *edit = new KLineEdit( this, "mywidget" );
- * KCompletion *comp = edit->completionObject();
+ * TDECompletion *comp = edit->completionObject();
* // Connect to the return pressed signal - optional
* connect(edit,TQT_SIGNAL(returnPressed(const TQString&)),comp,TQT_SLOT(addItem(const TQString&)));
* \endcode
@@ -127,7 +127,7 @@ class KURL;
* edit->setHandleSignals( false );
*
* // Set your own key-bindings for a text completion mode.
- * edit->setKeyBinding( KCompletionBase::TextCompletion, Qt::End );
+ * edit->setKeyBinding( TDECompletionBase::TextCompletion, Qt::End );
*
* // Hide the context (popup) menu
* edit->setContextMenuEnabled( false );
@@ -142,7 +142,7 @@ class KURL;
* @author Dawit Alemayehu <adawit@kde.org>
*/
-class TDEUI_EXPORT KLineEdit : public TQLineEdit, public KCompletionBase
+class TDEUI_EXPORT KLineEdit : public TQLineEdit, public TDECompletionBase
{
friend class KComboBox;
@@ -197,12 +197,12 @@ public:
void cursorAtEnd() { end( false ); }
/**
* Re-implemented from KCompletionBase for internal reasons.
*
* This function is re-implemented in order to make sure that
* the EchoMode is acceptable before we set the completion mode.
*
- * See KCompletionBase::setCompletionMode
+ * See TDECompletionBase::setCompletionMode
*/
virtual void setCompletionMode( TDEGlobalSettings::Completion mode );
@@ -275,12 +275,12 @@ public:
* @param create Set this to false if you don't want the box to be created
* i.e. to test if it is available.
*/
- KCompletionBox * completionBox( bool create = true );
+ TDECompletionBox * completionBox( bool create = true );
/**
* Reimplemented for internal reasons, the API is not affected.
*/
- virtual void setCompletionObject( KCompletion *, bool hsig = true );
+ virtual void setCompletionObject( TDECompletion *, bool hsig = true );
/**
* Reimplemented for internal reasons, the API is not affected.
@@ -323,10 +323,10 @@ public:
* TDEGlobalSettings::CompletionPopup.
* This will do nothing if a completion-box already exists.
*
* @param box The KCompletionBox to set
* @since 3.4
*/
- void setCompletionBox( KCompletionBox *box );
+ void setCompletionBox( TDECompletionBox *box );
/**
* This makes the line edit display a grayed-out hinting text as long as
@@ -385,7 +385,7 @@ signals:
* mode is set to @p TDEGlobalSettings::CompletionNone or
* @p echoMode() is @em not normal.
*/
- void textRotation( KCompletionBase::KeyBindingType );
+ void textRotation( TDECompletionBase::KeyBindingType );
/**
* Emitted when the user changed the completion mode by using the
@@ -424,10 +424,10 @@ public slots:
*
* @param type The key-binding invoked.
*/
- void rotateText( KCompletionBase::KeyBindingType type );
+ void rotateText( TDECompletionBase::KeyBindingType type );
/**
- * See KCompletionBase::setCompletedText.
+ * See TDECompletionBase::setCompletedText.
*/
virtual void setCompletedText( const TQString& );
@@ -63,7 +63,7 @@ class KURL;
* This widget by default creates a completion object when you invoke
* the completionObject( bool ) member function for the first time or
- * use setCompletionObject( KCompletion*, bool ) to assign your own
+ * use setCompletionObject( TDECompletion*, bool ) to assign your own
* completion object. Additionally, to make this widget more functional,
* KLineEdit will by default handle the text rotation and completion
@@ -82,7 +82,7 @@ class KURL;
* the completion mode will always be defaulted to TDEGlobalSettings::CompletionNone.
* This is done purposefully to guard against protected entries such as passwords being
- * cached in KCompletion's list. Hence, if the @p EchoMode is not TQLineEdit::Normal, the
+ * cached in TDECompletion's list. Hence, if the @p EchoMode is not TQLineEdit::Normal, the
* completion mode is automatically disabled.
*
@@ -197,12 +197,12 @@ public:
void cursorAtEnd() { end( false ); }
/**
- * Re-implemented from KCompletionBase for internal reasons.
+ * Re-implemented from TDECompletionBase for internal reasons.
*
* This function is re-implemented in order to make sure that
@@ -323,10 +323,10 @@ public:
* This will do nothing if a completion-box already exists.
*
- * @param box The KCompletionBox to set
+ * @param box The TDECompletionBox to set
* @since 3.4
*/